Module commands

Module commands 

CLI command definitions using clap.

This module contains the command-line interface definitions for linthis, including the main CLI struct and all subcommand enums.

Structs

Cli
Main CLI parser for linthis.

Enums

AgentFixProvider
AI agent CLI providers for automatic fix on hook failure (–type *-with-agent)
AgentProvider
AI coding agent providers (for skills/settings installation, –type agent)
BackupCommands
Backup subcommands
CacheCommands
Cache subcommands
Commands
Top-level subcommands
ConfigCommands
Config subcommands
ConfigField
Configuration field types for CLI operations
HookCommands
Hook subcommands
HookEvent
Git hook event types
HookTool
Hook management tools
PluginCommands
Plugin subcommands
ReportCommands
Report subcommands
ShellCommands
Subcommands for linthis shell.