pub struct RuleFilter { /* private fields */ }Expand description
Filter for applying rule disable/enable and severity overrides.
Implementations
Sourceimpl RuleFilter
impl RuleFilter
Sourcepub fn from_config(config: &RulesConfig) -> Self
pub fn from_config(config: &RulesConfig) -> Self
Create a rule filter from a RulesConfig.
Sourcepub fn merge_language_config(&mut self, lang_rules: Option<&RulesConfig>)
pub fn merge_language_config(&mut self, lang_rules: Option<&RulesConfig>)
Merge language-specific rules config.
Sourcepub fn is_disabled(&self, code: &str) -> bool
pub fn is_disabled(&self, code: &str) -> bool
Check if a rule code is disabled.
Sourcepub fn get_severity_override(&self, code: &str) -> Option<SeverityOverride>
pub fn get_severity_override(&self, code: &str) -> Option<SeverityOverride>
Get the severity override for a rule code, if any.
Sourcepub fn filter_issues(&self, issues: Vec<LintIssue>) -> Vec<LintIssue>
pub fn filter_issues(&self, issues: Vec<LintIssue>) -> Vec<LintIssue>
Filter a list of issues, removing disabled rules and applying severity overrides.
Sourcepub fn stats(&self) -> FilterStats
pub fn stats(&self) -> FilterStats
Get statistics about the filter configuration.