pub fn detect_install_method() -> InstallMethodExpand description
Detect how linthis was installed by inspecting the current executable path.
pub fn detect_install_method() -> InstallMethodDetect how linthis was installed by inspecting the current executable path.