CLI command definitions using clap.
This module contains the command-line interface definitions for linthis, including the main CLI struct and all subcommand enums.
Structs
- Cli
- Main CLI parser for linthis.
Enums
- Agent
FixProvider - AI agent CLI providers for automatic fix on hook failure (–type *-with-agent)
- Agent
Provider - AI coding agent providers (for skills/settings installation, –type agent)
- Backup
Commands - Backup subcommands
- Cache
Commands - Cache subcommands
- Commands
- Top-level subcommands
- Config
Commands - Config subcommands
- Config
Field - Configuration field types for CLI operations
- Hook
Commands - Hook subcommands
- Hook
Event - Git hook event types
- Hook
Tool - Hook management tools
- Plugin
Commands - Plugin subcommands
- Report
Commands - Report subcommands
- Shell
Commands - Subcommands for
linthis shell.